Name:           rapidfuzz-cpp
Version:        3.3.2
Release:        %mkrel 1
License:        MIT
Group:          Development/C++
Summary:        A fast string matching header-only library for C++
URL:            https://github.com/rapidfuzz/rapidfuzz-cpp
Source0:        https://github.com/rapidfuzz/rapidfuzz-cpp/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:         remove-march-native.patch
# Header only library
BuildArch:      noarch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  cmake(Catch2)

%description
RapidFuzz is a fast string matching library for Python and C++, which is using
the string similarity calculations from FuzzyWuzzy. However there are two
aspects that set RapidFuzz apart from FuzzyWuzzy:

1. It is MIT licensed so it can be used whichever License you might want to
   choose for your project, while you're forced to adopt the GPL license when
   using FuzzyWuzzy

2. It is mostly written in C++ and on top of this comes with a lot of
   Algorithmic improvements to make string matching even faster, while still
   providing the same results.

This is the C++ component of RapidFuzz, the Python library is available in the
python-rapidfuzz package.

%package devel
Summary:        Development files for the RapidFuzz C++ library
Group:          Development/C++
Provides:       %{name}-static = %{version}

%description devel
RapidFuzz is a fast string matching library for Python and C++, which is using
the string similarity calculations from FuzzyWuzzy. However there are two
aspects that set RapidFuzz apart from FuzzyWuzzy:

1. It is MIT licensed so it can be used whichever License you might want to
   choose for your project, while you're forced to adopt the GPL license when
   using FuzzyWuzzy

2. It is mostly written in C++ and on top of this comes with a lot of
   Algorithmic improvements to make string matching even faster, while still
   providing the same results.

This is the C++ component of RapidFuzz, the Python library is available in the
python-rapidfuzz package.

%prep
%autosetup -p1

# Change the group name, mainly so that the manpage is named meaningfully
sed -i 's/defgroup Fuzz Fuzz/defgroup rapidfuzz rapidfuzz/' rapidfuzz/fuzz.hpp
# Enable man generation, but don't enable the links since it produces files
# which aren't named specifically for rapidfuzz, such as "ratio" and
# "partial_ratio".
echo "GENERATE_MAN           = YES" >> Doxyfile
# There doesn't seem to be a reasonable way to comply with bundling guidelines
# where there is arbitrary jquery and similar bundled in the HTML generated by
# doxygen, so don't use it.
echo "GENERATE_HTML          = NO" >> Doxyfile

# install cmake config files into "/usr/share/cmake/" dir
sed -i 's|${CMAKE_INSTALL_LIBDIR}/cmake|${CMAKE_INSTALL_DATADIR}/cmake|' CMakeLists.txt

%build
%cmake -DRAPIDFUZZ_BUILD_TESTING=ON
%cmake_build

# Build the doxygen man doc
doxygen

%install
%cmake_install

mkdir -p %{buildroot}%{_mandir}/man3/
# Only install rapidfuzz.3, which is named specifically for this package, and
# not the generic "citelist.3".
cp doxygen/man/man3/rapidfuzz.3 %{buildroot}/%{_mandir}/man3/

%check
%ctest

%files devel
%license LICENSE
%doc README.md CHANGELOG.md
%{_includedir}/rapidfuzz/
%{_datadir}/cmake/rapidfuzz/
%{_mandir}/man3/rapidfuzz.3*


%changelog
* Wed Apr 02 2025 daviddavid <daviddavid> 3.3.2-1.mga10
+ Revision: 2172587
- new version: 3.3.2

* Sun Feb 02 2025 daviddavid <daviddavid> 3.3.1-1.mga10
+ Revision: 2144709
- initial package rapidfuzz-cpp

